@@ -61,10 +61,10 @@ bl_ccc_get_type (void)
 	(GInstanceInitFunc) bl_ccc_init,
       };
 
-      ccc_type = g_type_register_static (G_TYPE_OBJECT, 
+      ccc_type = g_type_register_static (G_TYPE_OBJECT,
                                          "BlCcc", &ccc_info, 0);
     }
-  
+
   return ccc_type;
 }
 
@@ -97,9 +97,7 @@ bl_ccc_init (BlCcc *ccc)
 static void
 bl_ccc_finalize (GObject *object)
 {
-  BlCcc *ccc;
-
-  ccc = BL_CCC (object);
+  BlCcc *ccc = BL_CCC (object);
 
   if (ccc->mutex)
     {
@@ -145,9 +143,11 @@ isdn_incoming_call (BlIsdn     *isdn,
 
   active = ccc->active_app;
 
+#if 0
   /* if the line matches this is the call we already handle */
   if (active && active->line == line)
     return;
+#endif
 
   app = bl_config_select_app (ccc->config, line->called_number);
 
@@ -177,36 +177,21 @@ isdn_incoming_call (BlIsdn     *isdn,
     {
       if (app == active)
         {
-          if (ccc->theater->item && ccc->theater->item->module)
+         if (ccc->theater->item && ccc->theater->item->module)
             {
               BModule *module = ccc->theater->item->module;
 
               if (module->num_players <
                   B_MODULE_GET_CLASS (module)->max_players)
                 {
-#if 0
-                  BModuleEvent event;
-
-                  bl_isdn_call_accept (isdn, line, app->vamp);
-
-                  app->line2 = line;
-
-                  /*  add a player to the module  */
-                  event.device_id = line->channel - 1;
-                  event.type      = B_EVENT_TYPE_PLAYER_ENTERED;
-                  event.key       = 0;
-
-                  bl_ccc_event (ccc, &event);
-
-                  return;
-#endif
+                  goto accept;
                 }
             }
         }
 
       if (app->priority > active->priority)
         {
-          /* FIXME: change apps */ 
+          /* FIXME: change apps */
         }
 
       g_printerr (" -> sorry, we are busy.\n");
@@ -214,9 +199,11 @@ isdn_incoming_call (BlIsdn     *isdn,
       return;
     }
 
-  bl_isdn_call_accept (isdn, line, app->vamp);
+ accept:
 
   line->app = app;
+  g_printerr ("Accepting the call on line %d.\n", line->channel);
+  bl_isdn_call_accept (isdn, line, app->sound, app->sound_loop);
 }
 
 static void
@@ -224,7 +211,7 @@ isdn_state_changed (BlIsdn     *isdn,
                     BlIsdnLine *line,
                     BlCcc      *ccc)
 {
-  BModuleEvent event;
+  BModuleEvent  event;
 
   g_printerr ("Line %d went %s.\n",
               line->channel, line->offhook ? "offhook" : "onhook");
@@ -234,16 +221,19 @@ isdn_state_changed (BlIsdn     *isdn,
 
   if (line->offhook)
     {
-      BlApp          *app  = line->app;
-      BlPlaylistItem *item = BL_PLAYLIST_ITEM (app);
+      BlApp *app  = line->app;
 
       g_mutex_lock (ccc->mutex);
 
-      ccc->active_app = app;
-      app->line       = line;
+      if (ccc->active_app != app)
+        {
+          ccc->active_app = app;
 
-      bl_theater_push_item (ccc->theater, item);
-      bl_theater_play (ccc->theater);
+          bl_theater_push_item (ccc->theater, BL_PLAYLIST_ITEM (app));
+          bl_theater_play (ccc->theater);
+        }
+
+      app->lines = g_list_prepend (app->lines, line);
 
       g_mutex_unlock (ccc->mutex);
 
@@ -256,10 +246,11 @@ isdn_state_changed (BlIsdn     *isdn,
     }
   else
     {
-      gboolean item_pushed;
+      BlApp    *app  = line->app;
+      gboolean  item_pushed;
 
       /* EEK */
-      item_pushed = (ccc->theater->item == BL_PLAYLIST_ITEM (line->app));
+      item_pushed = (ccc->theater->item == BL_PLAYLIST_ITEM (app));
 
       if (item_pushed)
         {
@@ -273,10 +264,10 @@ isdn_state_changed (BlIsdn     *isdn,
 
       g_mutex_lock (ccc->mutex);
 
-      line->app->line = NULL;
-      line->app       = NULL;
+      app->lines = g_list_remove (app->lines, line);
+      line->app = NULL;
 
-      if (item_pushed)
+      if (item_pushed && !app->lines)
         bl_theater_finish (ccc->theater);
 
       g_mutex_unlock (ccc->mutex);
@@ -290,7 +281,7 @@ isdn_key_pressed (BlIsdn     *isdn,
                   BlCcc      *ccc)
 {
   BModuleEvent  event;
-  
+
   if (! ccc->active_app)
     return;
 
@@ -319,11 +310,16 @@ theater_item_finished (BlTheater      *theater,
 {
   if (ccc->active_app)
     {
-      if (ccc->isdn && ccc->active_app->line)
+      if (ccc->isdn && ccc->active_app->lines)
         {
-          bl_isdn_call_hangup (ccc->isdn,
-                               ccc->active_app->line,
-                               BL_ISDN_REASON_NORMAL_CALL_CLEARING);
+          GList *list;
+
+          for (list = ccc->active_app->lines; list; list = list->next)
+            {
+              bl_isdn_call_hangup (ccc->isdn,
+                                   list->data,
+                                   BL_ISDN_REASON_NORMAL_CALL_CLEARING);
+            }
         }
 
       ccc->active_app = NULL;
@@ -342,7 +338,7 @@ theater_item_finished (BlTheater      *theater,
 
           if (! item)
             {
-              /* reload the playlist menually because calling
+              /* reload the playlist manually because calling
                *  bl_ccc_reload() will cause a recursive mutex
                *  deadlock
                */
@@ -393,7 +389,7 @@ bl_ccc_setup_applications (BlCcc *ccc)
     }
 }
 
-BlCcc * 
+BlCcc *
 bl_ccc_new (BlConfig *config)
 {
   BlCcc     *ccc;
@@ -434,13 +430,13 @@ bl_ccc_new (BlConfig *config)
     {
       bl_ccc_setup_applications (ccc);
 
-      g_signal_connect (G_OBJECT (ccc->isdn), "incoming_call", 
-                        G_CALLBACK (isdn_incoming_call), 
+      g_signal_connect (G_OBJECT (ccc->isdn), "incoming_call",
+                        G_CALLBACK (isdn_incoming_call),
                         ccc);
-      g_signal_connect (G_OBJECT (ccc->isdn), "state_changed", 
-                        G_CALLBACK (isdn_state_changed), 
+      g_signal_connect (G_OBJECT (ccc->isdn), "state_changed",
+                        G_CALLBACK (isdn_state_changed),
                         ccc);
-      g_signal_connect (G_OBJECT (ccc->isdn), "key_pressed", 
+      g_signal_connect (G_OBJECT (ccc->isdn), "key_pressed",
                         G_CALLBACK (isdn_key_pressed),
                         ccc);
     }
@@ -467,9 +463,9 @@ bl_ccc_status (BlCcc *ccc)
 
   if (ccc->playlist)
     {
-      g_string_append_printf (status, "Playlist is '%s' with %d items.\n", 
+      g_string_append_printf (status, "Playlist is '%s' with %d items.\n",
                               b_object_get_name (B_OBJECT (ccc->playlist)),
-                              g_list_length (ccc->playlist->items));
+                              bl_playlist_length (ccc->playlist));
     }
   else
     {
@@ -610,18 +606,14 @@ bl_ccc_load (BlCcc       *ccc,
              const gchar *filename,
              gboolean     instant_change)
 {
-  BlConfig       *config;
-  BlPlaylist     *new;
-  BlPlaylistItem *item;
+  BlPlaylist *new;
 
   g_return_val_if_fail (BL_IS_CCC (ccc), FALSE);
   g_return_val_if_fail (filename != NULL, FALSE);
 
   g_mutex_lock (ccc->mutex);
 
-  config = ccc->config;
-
-  new = bl_playlist_new_from_file (filename, config,
+  new = bl_playlist_new_from_file (filename, ccc->config,
                                    bl_theater_paint_callback, ccc->theater);
 
   if (new)
@@ -632,6 +624,8 @@ bl_ccc_load (BlCcc       *ccc,
 
       if (!ccc->theater->item)
         {
+          BlPlaylistItem *item;
+
           item = bl_playlist_load_next_item (ccc->playlist, FALSE);
 
           if (item)
@@ -641,8 +635,8 @@ bl_ccc_load (BlCcc       *ccc,
         {
           bl_theater_finish (ccc->theater);
         }
-    }      
-  
+    }
+
   g_mutex_unlock (ccc->mutex);
 
   return (new != NULL);
@@ -654,12 +648,12 @@ bl_ccc_list (BlCcc *ccc)
   gchar *retval = NULL;
 
   g_return_val_if_fail (BL_IS_CCC (ccc), NULL);
-  
+
   g_mutex_lock (ccc->mutex);
-  
+
   if (ccc->playlist)
     retval = bl_playlist_item_describe (BL_PLAYLIST_ITEM (ccc->playlist));
-  
+
   g_mutex_unlock (ccc->mutex);
 
   return retval;
@@ -678,7 +672,7 @@ bl_ccc_next (BlCcc *ccc)
 
   if (ccc->theater->item)
     retval = bl_playlist_item_describe (ccc->theater->item);
- 
+
   g_mutex_unlock (ccc->mutex);
 
   return retval;
@@ -724,7 +718,7 @@ bl_ccc_add (BlCcc        *ccc,
   g_mutex_lock (ccc->mutex);
 
   success = bl_theater_add_recipient (ccc->theater, host, error);
- 
+
   g_mutex_unlock (ccc->mutex);
 
   return success;
@@ -797,7 +791,7 @@ void
 bl_ccc_isdn_block (BlCcc *ccc)
 {
   g_return_if_fail (BL_IS_CCC (ccc));
-  
+
   if (ccc->isdn)
     bl_isdn_block (ccc->isdn);
 
@@ -808,7 +802,7 @@ void
 bl_ccc_isdn_unblock (BlCcc *ccc)
 {
   g_return_if_fail (BL_IS_CCC (ccc));
-  
+
   if (ccc->isdn)
     bl_isdn_unblock (ccc->isdn);
 }
