@@ -82,7 +82,7 @@ static GSourceFuncs udp_funcs =
   NULL
 };
 
-enum 
+enum
 {
   INCOMING_CALL,
   STATE_CHANGED,
@@ -126,7 +126,7 @@ udp_prepare (GSource *source,
                   "        from the ISDN system. I'll try to reconnect ...\n",
                   RESET_TIMEOUT);
 
-      bl_isdn_teardown (isdn);      
+      bl_isdn_teardown (isdn);
       bl_isdn_setup (isdn, NULL);
     }
 
@@ -167,7 +167,7 @@ udp_dispatch (GSource     *source,
           FD_SET (isdn->listen_sock, &set);
           tv.tv_sec  = 0;
           tv.tv_usec = 0;
-          
+
           if (FD_ISSET (isdn->listen_sock, &set))
             read (isdn->listen_sock, buffer, sizeof (buffer));
         }
@@ -196,7 +196,7 @@ udp_dispatch (GSource     *source,
             }
         }
     }
-  
+
   return TRUE;
 }
 
@@ -222,11 +222,11 @@ bl_isdn_get_type (void)
 	(GInstanceInitFunc) bl_isdn_init,
       };
 
-      isdn_type = g_type_register_static (G_TYPE_OBJECT, 
+      isdn_type = g_type_register_static (G_TYPE_OBJECT,
                                           "BlIsdn",
                                           &isdn_info, 0);
     }
-  
+
   return isdn_type;
 }
 
@@ -239,7 +239,7 @@ bl_isdn_class_init (BlIsdnClass *class)
 
   object_class = G_OBJECT_CLASS (class);
 
-  bl_isdn_signals[INCOMING_CALL] = 
+  bl_isdn_signals[INCOMING_CALL] =
     g_signal_new ("incoming_call",
 		  G_TYPE_FROM_CLASS (class),
 		  G_SIGNAL_RUN_FIRST,
@@ -247,7 +247,7 @@ bl_isdn_class_init (BlIsdnClass *class)
 		  NULL, NULL,
 		  bl_marshal_VOID__POINTER,
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
-  bl_isdn_signals[STATE_CHANGED] = 
+  bl_isdn_signals[STATE_CHANGED] =
     g_signal_new ("state_changed",
 		  G_TYPE_FROM_CLASS (class),
 		  G_SIGNAL_RUN_FIRST,
@@ -255,7 +255,7 @@ bl_isdn_class_init (BlIsdnClass *class)
 		  NULL, NULL,
 		  bl_marshal_VOID__POINTER,
 		  G_TYPE_NONE, 1, G_TYPE_POINTER);
-  bl_isdn_signals[KEY_PRESSED] = 
+  bl_isdn_signals[KEY_PRESSED] =
     g_signal_new ("key_pressed",
     		  G_TYPE_FROM_CLASS (class),
 		  G_SIGNAL_RUN_FIRST,
@@ -358,7 +358,7 @@ bl_isdn_setup (BlIsdn  *isdn,
   port = ntohs (addr.sin_port);
 
   memset (&addr, 0, sizeof (addr));
-  
+
   addr.sin_family = AF_INET;
   addr.sin_port   = htons (config->isdn_port);
   memcpy (&addr.sin_addr.s_addr, dest->h_addr_list[0], dest->h_length);
@@ -390,7 +390,7 @@ bl_isdn_setup (BlIsdn  *isdn,
     }
 
   cmd = g_strdup_printf ("0:register:%d", port);
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
   g_printerr ("BlIsdn > %s\n", cmd);
 #endif
   if (send (isdn->send_sock, cmd, strlen (cmd), 0) == -1)
@@ -444,12 +444,12 @@ bl_isdn_hangup_all (BlIsdn *isdn)
       if (line->offhook)
         {
           gchar *msg = g_strdup_printf ("%d:hangup", i + 1);
-          
+
           send (isdn->send_sock, msg, strlen (msg), 0);
 
           line->offhook = FALSE;
           if (!isdn->blocked)
-            g_signal_emit (G_OBJECT (isdn), 
+            g_signal_emit (G_OBJECT (isdn),
                            bl_isdn_signals[STATE_CHANGED], 0, line, NULL);
 
           g_free (line->called_number);
@@ -464,7 +464,7 @@ bl_isdn_heartbeat (BlIsdn *isdn)
   const gchar *msg = "0:heartbeat";
 
   send (isdn->send_sock, msg, strlen (msg), 0);
-  
+
   return TRUE;
 }
 
@@ -510,11 +510,11 @@ bl_isdn_handle_message (BlIsdn *isdn,
         {
           if (strncmp (msg, "onhook", 6) == 0)
             {
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
               g_printerr ("BlIsdn: Line %d hung up\n", channel);
 #endif
               line->offhook = FALSE;
-              g_signal_emit (G_OBJECT (isdn), 
+              g_signal_emit (G_OBJECT (isdn),
                              bl_isdn_signals[STATE_CHANGED], 0, line);
 
               g_free (line->calling_number);
@@ -545,11 +545,11 @@ bl_isdn_handle_message (BlIsdn *isdn,
                   return;
                 }
 
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
               g_printerr ("BlIsdn: Key %c pressed on line %d\n",
                           msg[5], channel);
 #endif
-              g_signal_emit (G_OBJECT (isdn), 
+              g_signal_emit (G_OBJECT (isdn),
                              bl_isdn_signals[KEY_PRESSED], 0, line, key);
               return;
             }
@@ -560,11 +560,11 @@ bl_isdn_handle_message (BlIsdn *isdn,
             {
               gchar *caller = msg + 6;
               gchar *called;
-              
+
               if ((called = strchr (caller, ':')))
                 *called++ = '\0';
-              
-#if ISDN_VERBOSE              
+
+#if ISDN_VERBOSE
               g_printerr ("BlIsdn: incoming call on line %d from %s to %s\n",
                           channel, caller, called);
 #endif
@@ -574,13 +574,13 @@ bl_isdn_handle_message (BlIsdn *isdn,
               g_free (line->calling_number);
               line->calling_number = g_strdup (caller);
 
-              g_signal_emit (G_OBJECT (isdn), 
+              g_signal_emit (G_OBJECT (isdn),
                              bl_isdn_signals[INCOMING_CALL], 0, line);
               return;
             }
           else if (strncmp (msg, "connected", 9) == 0)
             {
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
               g_printerr ("BlIsdn: line %d connected\n", channel);
 #endif
               line->offhook = TRUE;
@@ -607,7 +607,7 @@ bl_isdn_handle_message (BlIsdn *isdn,
     }
 }
 
-BlIsdn * 
+BlIsdn *
 bl_isdn_new (BlConfig  *config,
              GError   **error)
 {
@@ -643,7 +643,7 @@ bl_isdn_new (BlConfig  *config,
 
   isdn->num_lines = config->isdn_lines;
   isdn->lines   = g_new0 (BlIsdnLine, isdn->num_lines);
-  
+
   for (i = 0; i < isdn->num_lines; i++)
     isdn->lines[i].channel = i + 1;
 
@@ -660,7 +660,8 @@ bl_isdn_new (BlConfig  *config,
 void
 bl_isdn_call_accept (BlIsdn      *isdn,
                      BlIsdnLine  *line,
-                     const gchar *wamp)
+                     const gchar *sound,
+                     const gchar *sound_loop)
 {
   gchar *cmd;
 
@@ -671,16 +672,28 @@ bl_isdn_call_accept (BlIsdn      *isdn,
     return;
 
   cmd = g_strdup_printf ("%d:accept", line->channel);
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
   g_printerr ("BlIsdn > %s\n", cmd);
 #endif
   send (isdn->send_sock, cmd, strlen (cmd), 0);
   g_free (cmd);
 
-  if (wamp)
+  if (sound_loop || sound)
     {
-      cmd = g_strdup_printf ("%d:playbackground:%s", line->channel, wamp);
-#if ISDN_VERBOSE              
+      cmd = g_strdup_printf ("%d:playbackground:%s",
+                             line->channel,
+                             sound_loop ? sound_loop : sound);
+#if ISDN_VERBOSE
+  g_printerr ("BlIsdn > %s\n", cmd);
+#endif
+      send (isdn->send_sock, cmd, strlen (cmd), 0);
+      g_free (cmd);
+    }
+
+  if (sound_loop && sound)
+    {
+      cmd = g_strdup_printf ("%d:play:%s", line->channel, sound);
+#if ISDN_VERBOSE
   g_printerr ("BlIsdn > %s\n", cmd);
 #endif
       send (isdn->send_sock, cmd, strlen (cmd), 0);
@@ -703,7 +716,7 @@ bl_isdn_call_hangup (BlIsdn       *isdn,
   else
     cmd = g_strdup_printf ("%d:hangup", line->channel);
 
-#if ISDN_VERBOSE              
+#if ISDN_VERBOSE
   g_printerr ("BlIsdn > %s\n", cmd);
 #endif
   send (isdn->send_sock, cmd, strlen (cmd), 0);
