@@ -26,11 +26,13 @@ G_BEGIN_DECLS
 typedef struct _BlApp          BlApp;
 typedef struct _BlCcc          BlCcc;
 typedef struct _BlConfig       BlConfig;
+typedef struct _BlDispatch     BlDispatch;
 typedef struct _BlEffects      BlEffects;
 typedef struct _BlIsdn         BlIsdn;
 typedef struct _BlIsdnLine     BlIsdnLine;
 typedef struct _BlListen       BlListen;
 typedef struct _BlLoveletters  BlLoveletters;
+typedef struct _BlLovemodules  BlLovemodules;
 typedef struct _BlLogger       BlLogger;
 typedef struct _BlOnDemand     BlOnDemand;
 typedef struct _BlPlaylist     BlPlaylist;
